##  Creating a Template for Import
The exported Excel file also serves as a template for importing data, as it includes the necessary columns for fact sheet fields in the proper format.
To create an import template, follow the instructions in the section [Exporting Fact Sheet Data as an Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759eb787a441014923281e9be89d344__exporting_fact_sheet_data_as_an_excel_file), and adhere to these best practices while preparing:
  * Every attribute you add to the inventory table as a column will be a column in the exported spreadsheet. In the inventory table, include only those columns that you want to update to avoid unnecessary or accidental overwriting of other fields.
  * To update fields on relations, ensure that the import template also includes a '<field on relation display name>' column to identify or establish the target relation. For more, see the formatting rules for [Fields on Relation](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a86917a441014872eecad909f5e9e__fields_on_relation).
  * Create a new template for each import.


If the inventory and fact sheets already contain data, the selected columns in the exported Excel file will be partially or fully filled, and the ID column will display the fact sheet ID generated by SAP LeanIX. You can then update the data in these columns and import the file back into SAP LeanIX. To learn how to import, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
![The Exported Excel File Acts as an Import Template](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752f7647a4410149c17a9e397376123_LowRes.png)
The Exported Excel File Acts as an Import Template
If the inventory does not have any existing data, the exported Excel file will include only the selected column names. All other rows, starting from row 3, will be empty.
YesNo
Send
